// Copyright 2019-2022 Parity Technologies (UK) Ltd.
// This file is part of subxt.
//
// subxt is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// subxt is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with subxt.  If not, see <http://www.gnu.org/licenses/>.

//! For working with events.

mod decoding;
mod event_subscription;
mod events_type;
mod filter_events;

pub use decoding::EventsDecodingError;
pub use event_subscription::{
    subscribe,
    subscribe_finalized,
    subscribe_to_block_headers_filling_in_gaps,
    EventSub,
    EventSubscription,
    FinalizedEventSub,
};
pub use events_type::{
    at,
    EventDetails,
    Events,
    RawEventDetails,
};
pub use filter_events::{
    EventFilter,
    FilterEvents,
    FilteredEventDetails,
};
